package
Version:
v0.0.0-...-dcce261
Opens a new window with list of versions in this module.
Published: Sep 28, 2017
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func IsHas(i interface{}) bool
func StructToMap(i interface{}) (m map[string]interface{})
Source Files
¶
Click to show internal directories.
Click to hide internal directories.